@@ -345,9 +345,10 @@ class opensshStatus(StatusMenuItem):
                     self.wlanIP = "None"
                 if self.wlanIP != "None" and self.keepWifiPMOff:
                     system("sudo openssh-status.sh wlan_started")
+            if status == "DISCONNECTING":
+                system("sudo openssh-status.sh wlan_stopped")
             if status == "IDLE":
                 self.wlanIP = "None"
-                system("sudo openssh-status.sh wlan_stopped")
     
     def handleDisplay(self, displayStatus):
         if displayStatus == "on" or displayStatus == "dimmed":
@@ -481,16 +482,13 @@ class opensshStatus(StatusMenuItem):
         self.sshRunning = int(getoutput("ps aux | grep -c /usr/sbin/sshd")) - 2
         
     def sshUsers(self):
-        self.sshConnected = int(getoutput("netstat -t | grep -cE :ssh[[:space:]]*E{0}.*ESTABLISHED"))
+        self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
         
     def sshAllUsers(self):
-        self.sshConnected = int(getoutput("netstat -t | grep -cE :ssh[[:space:]]*E{0}.*ESTABLISHED"))
+        self.sshConnected = int(getoutput("netstat -t | grep -c :ssh[[:space:]]*[0-9].*ESTABLISHED"))
         sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
-        try:
-            if not "ESTABLISHED" in sshNetstat[0]:
-                sshNetstat = []
-        except:
-            pass
+        if sshNetstat[0] == "":
+            sshNetstat = []
         
         countInWLAN = 0
         countOutWLAN = 0
@@ -1078,11 +1076,8 @@ class opensshStatus(StatusMenuItem):
     def sshCountAll(self, dummy):
         self.sshUsers()
         sshNetstat = getoutput("netstat -t | grep :ssh.*ESTABLISHED").split("\n")
-        try:
-            if not "ESTABLISHED" in sshNetstat[0]:
-                sshNetstat = []
-        except:
-            pass
+        if sshNetstat[0] == "":
+            sshNetstat = []
         
         countInWLAN = 0
         countOutWLAN = 0
